@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from typing_extensions import override
+
 from pyinfra.api import FactBase
 
 from .util import make_cat_files_command
@@ -14,15 +16,20 @@ class DnfRepositories(FactBase):
 
         [
             {
-                "name": "CentOS-$releasever - Apps",
-                "baseurl": "http://mirror.centos.org/$contentdir/$releasever/Apps/$basearch/os/",
-                "gpgcheck": "1",
+                "repoid": "baseos",
+                "name": "AlmaLinux $releasever - BaseOS",
+                "mirrorlist": "https://mirrors.almalinux.org/mirrorlist/$releasever/baseos",
                 "enabled": "1",
-                "gpgkey": "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-centosofficial",
+                "gpgcheck": "1",
+                "countme": "1",
+                "gpgkey": "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-AlmaLinux-9",
+                "metadata_expire": "86400",
+                "enabled_metadata": "1"
             },
         ]
     """
 
+    @override
     def command(self) -> str:
         return make_cat_files_command(
             "/etc/dnf.conf",
@@ -30,10 +37,12 @@ class DnfRepositories(FactBase):
             "/etc/yum.repos.d/*.repo",
         )
 
+    @override
     def requires_command(self) -> str:
         return "dnf"
 
     default = list
 
+    @override
     def process(self, output):
         return parse_yum_repositories(output)
